==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_private/lang/en/login.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'forgot_password'=>'Forgot Password',
'explain_forgot_password'=>'If you lost your password, you can request a new one here. Please provide your username
and a mail will be sent to your e-mail address deposited in your profile. It will include further instructions.',
'inactive_cannot_get_new_password'=>'Your account is set inactive and cannot get a new password!',
'incorrect_username'=>'You have not given a valid username!',
'incorrect_password'=>'Your given password is not correct!',
'account_not_active'=>'Your account is not activated! Either you forgot to do this or you got banned.',
'you_are_now_logged_in'=>'You are now logged in our forum!',
'you_are_now_logged_out'=>'We have logged you out of our forum!',
'too_many_fail_logins'=>'You have provided a wrong password too often. Any further attempts will be blocked for fifteen minutes.',
'inactive_account_cannot_request_password'=>'Your account is set inactive and cannot assign the new password!',
'you_can_only_request_one_password'=>'You are only allowed to request one new password!',
'password_activation_sent'=>'We successfully sent the e-mail to your address.',
'password_activation_success'=>'Your new password is now ready for use.',
'reauth'=>'Renewing Login',
'explain_reauth'=>'Some of your provided data has changed since login. Therefore your
access token has become invalid and you may now put your password again to acquire a
new one.',
'auth_fail_taint'=>'Your access token has been marked as "tainted".',
'auth_fail_login_token_invalid'=>'Your access token is not correct.',
'auth_fail_lifetime_exceeded'=>'Your access token is too old and has expired.',
'auth_fail_ip_changed'=>'Your access token has a diverting ip address from the one fetched on login.',
'auth_fail_agent_changed'=>'Your access token has a diverting browser (user agent) from the one fetched on login.',
'reauth_success'=>'Your access token has been refreshed and is now valid again.',
'reauth_failed'=>'You have not provided your correct password. The token remains &quot;tainted&quot;.'
);
?>

==> larus_board-0.9.5.tbz: larus_board-0.9.5/lb_private/lang/en/login.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_not_active'=>'Your account is not activated! Either you forgot to do this or you got banned.',
'auth_fail_agent_changed'=>'Your access token has a diverting browser (user agent) from the one fetched on login.',
'auth_fail_ip_changed'=>'Your access token has a diverting ip address from the one fetched on login.',
'auth_fail_lifetime_exceeded'=>'Your access token is too old and has expired.',
'auth_fail_login_token_invalid'=>'Your access token is not correct.',
'auth_fail_taint'=>'Your access token has been marked as "tainted".',
'explain_forgot_password'=>'If you lost your password, you can request a new one here. Please provide your username and a mail will be sent to your e-mail address deposited in your profile. It will include further instructions.',
'explain_reauth'=>'Some of your provided data has changed since login. Therefore your access token has become invalid and you may now put your password again to acquire a new one.',
'forgot_password'=>'Forgot Password',
'inactive_account_cannot_request_password'=>'Your account is set inactive and cannot assign the new password!',
'inactive_cannot_get_new_password'=>'Your account is set inactive and cannot get a new password!',
'incorrect_password'=>'Your given password is not correct!',
'incorrect_username'=>'You have not given a valid username!',
'password_activation_sent'=>'We successfully sent the e-mail to your address.',
'password_activation_success'=>'Your new password is now ready for use.',
'reauth'=>'Renewing Login',
'reauth_failed'=>'You have not provided your correct password. The token remains "tainted".',
'reauth_success'=>'Your access token has been refreshed and is now valid again.',
'too_many_fail_logins'=>'You have provided a wrong password too often. Any further attempts will be blocked for fifteen minutes.',
'you_are_now_logged_in'=>'You are now logged in our forum!',
'you_are_now_logged_out'=>'We have logged you out of our forum!',
'you_can_only_request_one_password'=>'You are only allowed to request one new password!'
);
?>
